(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('rxjs'), require('@angular/core'), require('@angular/common/http'), require('rxjs/operators'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('ngx-drupal7-services', ['exports', 'rxjs', '@angular/core', '@angular/common/http', 'rxjs/operators', '@angular/common'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-drupal7-services'] = {}, global.rxjs, global.ng.core, global.ng.common.http, global.rxjs.operators, global.ng.common));
}(this, (function (exports, rxjs, core, http, operators, common) { 'use strict';

    /**
     * DrupalConstants singleton design pattern of the required settings and user connection.
     */
    // @dynamic
    var DrupalConstants = /** @class */ (function () {
        function DrupalConstants() {
            /**
             * handle offline error messages
             * @param err (optional) the error of the http request
             */
            this.handleOffline = function (err) {
                if (this.settings.allowOffline) {
                    return rxjs.of();
                }
                return rxjs.throwError(err);
            };
        }
        Object.defineProperty(DrupalConstants, "Instance", {
            get: function () {
                if (!this.instance) {
                    this.instance = new DrupalConstants();
                }
                return this.instance;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(DrupalConstants, "Settings", {
            /**
             * Handeling the case when user didn't implement the back-end settings and return the settings instance
             */
            get: function () {
                if (!this.Instance.settings) {
                    throw new Error('ngx-drupal7-services: Application settings are not set, Please read README.MD file');
                }
                return this.Instance.settings;
            },
            /**
             * Set the settings instanse on application init.
             * you can also do that at the runtime, Thanks to Singleton design pattern <3 !
             */
            set: function (newSettings) {
                this.Instance.settings = newSettings;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(DrupalConstants, "backEndUrl", {
            /**
             * the full backend url for current user settings
             */
            get: function () {
                var settings = this.Settings;
                var url = settings.apiProtocol + '://' + settings.apiHost;
                return settings.apiPort ? url + ':' + settings.apiPort + '/' : url + '/';
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(DrupalConstants, "restUrl", {
            /**
             * Application back-end rest api url.
             */
            get: function () {
                var settings = this.Settings;
                return this.backEndUrl + settings.apiEndPoint + '/';
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(DrupalConstants, "Connection", {
            /**
             * get the connection instance
             */
            get: function () {
                return this.Instance.connection;
            },
            /**
             * Updating connection instanse after login or rightaway after openning the connection
             */
            set: function (newConnection) {
                this.Instance.connection = newConnection;
            },
            enumerable: false,
            configurable: true
        });
        return DrupalConstants;
    }());

    /**
     * the main service is the basic http service of all other services "parent" that implements all the required request.
     * this service will add the headers automatically for each request it self
     */
    var MainService = /** @class */ (function () {
        /**
         * the main constractor of this service will inject the required services dynamically.
         * @param http basic http service
         * @param cookieService ngx-cookie service provider to save the cookies
         * @see https://angular.io/guide/dependency-injection
         * @see https://www.npmjs.com/package/ngx-cookie
         */
        function MainService(httpClient, platformId) {
            this.httpClient = httpClient;
            this.platformId = platformId;
        }
        /**
         * structure a full entity for drupal request
         * @param entity the entity to be structured
         * @param ignoredFields fields to be ignored just like nid or uid or title
         * @param fieldLabels: the label for each field just like "{field_custom_field: 'value'}"
         * @param language language of the entity
         */
        MainService.prototype.structureEntity = function (entity, ignoredFields, fieldLabels, language) {
            var _this = this;
            Object.keys(entity).forEach(function (key, index) {
                if (ignoredFields.indexOf(key) === -1) {
                    var fieldLabel = void 0;
                    if (fieldLabels[key]) {
                        fieldLabel = fieldLabels[key];
                    }
                    entity[key] = _this.structureField(entity[key], fieldLabel, language);
                }
            });
            return entity;
        };
        /**
         * structure the field for drupal services request
         * @param value the field value
         * @param label field label name
         * @param language language of the field
         */
        MainService.prototype.structureField = function (value, label, language) {
            var _a, _b, _c, _d;
            if (label === void 0) { label = 'value'; }
            if (!language) {
                language = DrupalConstants.Settings.language;
            }
            var item = {};
            if (this.isArray(value)) {
                var field_array = [];
                for (var i = 0, l = value.length; i < l; i++) {
                    item[label] = value[i];
                    field_array.push(item);
                }
                return _a = {},
                    _a[language] = field_array,
                    _a;
            }
            if (value instanceof Date) {
                var obj = {
                    value: {
                        date: value.getFullYear() + "-" + (value.getMonth() + 1) + "-" +
                            (value.getDate() + " " + value.getHours() + ":" + value.getMinutes() + ":" + value.getSeconds())
                    }
                };
                return _b = {},
                    _b[language] = [
                        obj
                    ],
                    _b;
            }
            // field value given with label(s) already built
            if (typeof value === 'object') {
                return _c = {},
                    _c[language] = [
                        value
                    ],
                    _c;
            }
            item[label] = value;
            return _d = {},
                _d[language] = [
                    item
                ],
                _d;
        };
        Object.defineProperty(MainService.prototype, "options", {
            /**
             * a getter to return the required headers for drupal
             * X-CSRF-Token - application token from services/session/connect
             * Content-Type - the type of the request content.
             * Accept - forcing drupal to return the response as a json object
             * @return object of the headers
             */
            get: function () {
                var headers = {
                    'Content-Type': 'application/json',
                    'Accept': 'application/json',
                };
                var token = this.getSavedVariable('token');
                if (token) {
                    headers['X-CSRF-Token'] = token;
                }
                headers['Authentication'] = this.getSavedVariable('session_name') + "=" + this.getSavedVariable('sessid');
                if (DrupalConstants.Settings.cookieHeader) {
                    headers['Cookie'] = this.getSavedVariable('session_name') + "=" + this.getSavedVariable('sessid');
                }
                var options = {
                    headers: headers,
                    withCredentials: true,
                    reportProgress: true,
                };
                return options;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * getting token from drupal services module
         * @return http text token response
         */
        MainService.prototype.getToken = function () {
            var _this = this;
            var options = this.options;
            options['responseType'] = 'text';
            return this.httpRequestWithConfig(this.httpClient.get(DrupalConstants.backEndUrl + "services/session/token", options)).pipe(operators.map(function (res) {
                if (!common.isPlatformServer(_this.platformId)) {
                    localStorage.setItem('token', res);
                }
                return res;
            }));
        };
        /**
         * Saving drupal session and token in cookies using ngx-cookie service
         * @param connection drupal connection
         */
        MainService.prototype.saveSessionToken = function (connection) {
            if (!connection.token) {
                connection.token = this.getSavedVariable('token');
            }
            this.removeSession();
            DrupalConstants.Connection = connection;
            if (!common.isPlatformServer(this.platformId)) {
                localStorage.setItem(connection.session_name, connection.sessid);
                localStorage.setItem('sessid', connection.sessid);
                localStorage.setItem('session_name', connection.session_name);
                localStorage.setItem('token', connection.token);
                if (connection.user && connection.user.timestamp) {
                    localStorage.setItem('timestamp', connection.user.timestamp.toString());
                }
                else {
                    localStorage.setItem('timestamp', Math.floor(Date.now()).toString());
                }
            }
        };
        /**
         * building up the full url path for each resource and / or params
         * @param resource the entity resource param. ex: system/'connect', user/'login'
         * @return full request path after adding the entity type and resource param
         */
        MainService.prototype.fullRequestURL = function (resource) {
            var request_url = DrupalConstants.restUrl;
            if (this.entityType) {
                request_url += this.entityType;
            }
            if (resource) {
                if (request_url[request_url.length - 1] === '/') {
                    request_url += resource;
                }
                else {
                    request_url += '/' + resource;
                }
            }
            return request_url;
        };
        /**
         * adding http request configs: request timeout, error handler
         * @param httpObservableRequest the http Observable to request
         * @return Observable of the request after adding required configs
         */
        MainService.prototype.httpRequestWithConfig = function (httpObservableRequest) {
            return httpObservableRequest.pipe(operators.timeout(DrupalConstants.Settings.requestTimeout), operators.catchError(function (err) { return DrupalConstants.Instance.handleOffline(err); }));
        };
        /**
         * basic http get request with headers.
         * @param resource the entity resource param. ex: system/'connect', user/'login'
         * @return http json response
         */
        MainService.prototype.get = function (resource) {
            return this.httpRequestWithConfig(this.httpClient.get(this.fullRequestURL(resource), this.options));
        };
        /**
         * basic http post request with headers.
         * @param resource the entity resource param. ex: system/'connect', user/'login'
         * @param body the contenct of the request
         * @return http json response
         */
        MainService.prototype.post = function (body, resource) {
            if (body === void 0) { body = {}; }
            return this.httpRequestWithConfig(this.httpClient.post(this.fullRequestURL(resource), body, this.options));
        };
        /**
         * basic http put request with headers.
         * @param resource the entity resource param. ex: system/'connect', user/'login'
         * @param body the contenct of the request
         * @return http json response
         */
        MainService.prototype.put = function (body, resource) {
            if (body === void 0) { body = {}; }
            return this.httpRequestWithConfig(this.httpClient.put(this.fullRequestURL(resource), body, this.options));
        };
        /**
         * basic http delete request with headers.
         * @param resource the entity resource param. ex: system/'connect', user/'login'
         * @return http json response
         */
        MainService.prototype.delete = function (resource) {
            return this.httpRequestWithConfig(this.httpClient.delete(this.fullRequestURL(resource), this.options));
        };
        /**
         * Clearing drupal session after logging out
         */
        MainService.prototype.removeSession = function () {
            if (!common.isPlatformServer(this.platformId)) {
                localStorage.removeItem('token');
                localStorage.removeItem('timestamp');
                localStorage.removeItem('sessid');
                localStorage.removeItem('session_name');
                if (DrupalConstants.Connection && DrupalConstants.Connection.session_name) {
                    localStorage.removeItem(DrupalConstants.Connection.session_name);
                }
            }
        };
        /**
         * Checking the current connection if the connection is init and valid
         * @return if connection is valid
         */
        MainService.prototype.isConnected = function () {
            return this.getSavedVariable('token') &&
                this.getSavedVariable('sessid') &&
                this.getSavedVariable('session_name') &&
                !this.isConnectionExpired() ?
                true : false;
        };
        /**
         * Check if the drupal session is timedout.
         * @return true if the current date is less than the login date by 24 day "drupal default session timeout is 24 day".
         */
        MainService.prototype.isConnectionExpired = function () {
            var nowTS = Math.floor(Date.now());
            var sessionDays = 23;
            if (DrupalConstants.Settings.sessionDays) {
                sessionDays = DrupalConstants.Settings.sessionDays;
            }
            var dayMS = 86400000; // 1 day to ms
            var expirationTS = sessionDays * dayMS;
            return nowTS - +this.getSavedVariable('timestamp') < expirationTS;
        };
        /**
         * Serializin arguments as a string
         * @param options object of drupal parametars to serialize
         * @return string of parameters
         */
        MainService.prototype.getArgs = function (options) {
            var _this = this;
            if (!options) {
                return '';
            }
            var args = '?';
            Object.keys(options).forEach(function (key, index) {
                args += _this.optionToString(key, options[key]);
            });
            return args;
        };
        /**
         * Check if variable is array of objects
         * @param value array to check
         */
        MainService.prototype.isArray = function (value) {
            return Object.prototype.toString.call(value) === '[object Array]';
        };
        /**
         * retrive the variable from the connection object or if there is no connection yet it will return them from the cookies
         * this will will allow you to implement your custom connection storage, just like ionic.
         * because the cookies is not always available on webview apps, you may need to save the connection in sqllite
         * and restore them directly.
         * @param variableName the name of the saved variable
         */
        MainService.prototype.getSavedVariable = function (variableName) {
            if (DrupalConstants.Connection) {
                if (DrupalConstants.Connection[variableName]) {
                    return DrupalConstants.Connection[variableName];
                }
                else if (DrupalConstants.Connection.user && DrupalConstants.Connection.user[variableName]) {
                    return DrupalConstants.Connection.user[variableName];
                }
            }
            if (!common.isPlatformServer(this.platformId)) {
                return localStorage.getItem(variableName);
            }
            return;
        };
        /**
         * serializing eatch option
         * @param key option key
         * @param value option value
         * @return single option serilization
         */
        MainService.prototype.optionToString = function (key, value) {
            var _this = this;
            if (!value) {
                return '';
            }
            var str = '';
            if (value instanceof Array) {
                value.forEach(function (element, index) {
                    str += key + "[" + index + "]=" + element + "&";
                });
            }
            else if (value instanceof Object) {
                Object.keys(value).forEach(function (element, index) {
                    if (value[element] instanceof Object) {
                        str += _this.serializeObject(value[element], key + "[" + element + "]");
                    }
                    else {
                        str += key + "[" + element + "]=" + value[element] + "&";
                    }
                });
            }
            else {
                str += key + "=" + value + "&";
            }
            return str;
        };
        /**
         * serializing the object keys
         * @param obj object to serialize
         */
        MainService.prototype.serializeObject = function (obj, parentSerialized) {
            var _this = this;
            var str = '';
            Object.keys(obj).forEach(function (key, index) {
                var value = obj[key];
                if (value instanceof Object) {
                    str += "" + _this.serializeObject(value, parentSerialized + "[" + key + "]");
                }
                else {
                    str += parentSerialized + "[" + key + "]=" + value + "&";
                }
            });
            return str;
        };
        return MainService;
    }());
    MainService.decorators = [
        { type: core.Injectable }
    ];
    /** @nocollapse */
    MainService.ctorParameters = function () { return [
        { type: http.HttpClient },
        { type: Object, decorators: [{ type: core.Inject, args: [core.PLATFORM_ID,] }] }
    ]; };

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global Reflect, Promise */
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        return extendStatics(d, b);
    };
    function __extends(d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }
    var __assign = function () {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    function __rest(s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    }
    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
            r = Reflect.decorate(decorators, target, key, desc);
        else
            for (var i = decorators.length - 1; i >= 0; i--)
                if (d = decorators[i])
                    r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }
    function __param(paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); };
    }
    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
            return Reflect.metadata(metadataKey, metadataValue);
    }
    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try {
                step(generator.next(value));
            }
            catch (e) {
                reject(e);
            } }
            function rejected(value) { try {
                step(generator["throw"](value));
            }
            catch (e) {
                reject(e);
            } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }
    function __generator(thisArg, body) {
        var _ = { label: 0, sent: function () { if (t[0] & 1)
                throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f)
                throw new TypeError("Generator is already executing.");
            while (_)
                try {
                    if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                        return t;
                    if (y = 0, t)
                        op = [op[0] & 2, t.value];
                    switch (op[0]) {
                        case 0:
                        case 1:
                            t = op;
                            break;
                        case 4:
                            _.label++;
                            return { value: op[1], done: false };
                        case 5:
                            _.label++;
                            y = op[1];
                            op = [0];
                            continue;
                        case 7:
                            op = _.ops.pop();
                            _.trys.pop();
                            continue;
                        default:
                            if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                _ = 0;
                                continue;
                            }
                            if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                _.label = op[1];
                                break;
                            }
                            if (op[0] === 6 && _.label < t[1]) {
                                _.label = t[1];
                                t = op;
                                break;
                            }
                            if (t && _.label < t[2]) {
                                _.label = t[2];
                                _.ops.push(op);
                                break;
                            }
                            if (t[2])
                                _.ops.pop();
                            _.trys.pop();
                            continue;
                    }
                    op = body.call(thisArg, _);
                }
                catch (e) {
                    op = [6, e];
                    y = 0;
                }
                finally {
                    f = t = 0;
                }
            if (op[0] & 5)
                throw op[1];
            return { value: op[0] ? op[1] : void 0, done: true };
        }
    }
    var __createBinding = Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        Object.defineProperty(o, k2, { enumerable: true, get: function () { return m[k]; } });
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    });
    function __exportStar(m, o) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                __createBinding(o, m, p);
    }
    function __values(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m)
            return m.call(o);
        if (o && typeof o.length === "number")
            return {
                next: function () {
                    if (o && i >= o.length)
                        o = void 0;
                    return { value: o && o[i++], done: !o };
                }
            };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    }
    function __read(o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m)
            return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                ar.push(r.value);
        }
        catch (error) {
            e = { error: error };
        }
        finally {
            try {
                if (r && !r.done && (m = i["return"]))
                    m.call(i);
            }
            finally {
                if (e)
                    throw e.error;
            }
        }
        return ar;
    }
    /** @deprecated */
    function __spread() {
        for (var ar = [], i = 0; i < arguments.length; i++)
            ar = ar.concat(__read(arguments[i]));
        return ar;
    }
    /** @deprecated */
    function __spreadArrays() {
        for (var s = 0, i = 0, il = arguments.length; i < il; i++)
            s += arguments[i].length;
        for (var r = Array(s), k = 0, i = 0; i < il; i++)
            for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                r[k] = a[j];
        return r;
    }
    function __spreadArray(to, from) {
        for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
            to[j] = from[i];
        return to;
    }
    function __await(v) {
        return this instanceof __await ? (this.v = v, this) : new __await(v);
    }
    function __asyncGenerator(thisArg, _arguments, generator) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var g = generator.apply(thisArg, _arguments || []), i, q = [];
        return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
        function verb(n) { if (g[n])
            i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
        function resume(n, v) { try {
            step(g[n](v));
        }
        catch (e) {
            settle(q[0][3], e);
        } }
        function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
        function fulfill(value) { resume("next", value); }
        function reject(value) { resume("throw", value); }
        function settle(f, v) { if (f(v), q.shift(), q.length)
            resume(q[0][0], q[0][1]); }
    }
    function __asyncDelegator(o) {
        var i, p;
        return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
        function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
    }
    function __asyncValues(o) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var m = o[Symbol.asyncIterator], i;
        return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
        function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
        function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
    }
    function __makeTemplateObject(cooked, raw) {
        if (Object.defineProperty) {
            Object.defineProperty(cooked, "raw", { value: raw });
        }
        else {
            cooked.raw = raw;
        }
        return cooked;
    }
    ;
    var __setModuleDefault = Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    };
    function __importStar(mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    }
    function __importDefault(mod) {
        return (mod && mod.__esModule) ? mod : { default: mod };
    }
    function __classPrivateFieldGet(receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    }
    function __classPrivateFieldSet(receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    }

    /**
     * system service for drupal
     * @see BACK_END/admin/structure/services/list/END_POINT/resources for more details
     */
    var SystemService = /** @class */ (function (_super) {
        __extends(SystemService, _super);
        function SystemService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            _this.entityType = 'system';
            return _this;
        }
        /**
         * if there is already a token in the browser cookies and it is not expired it will return it
         * this will fetch a new token before trying to connect
         * @param refreshToken boolean to force the application to request new token
         * @return observable of the connect method
         * the subscription data is an object of SystemConnection interface
         */
        SystemService.prototype.connect = function (refreshToken) {
            var _this = this;
            if (refreshToken === void 0) { refreshToken = false; }
            if (this.isConnectionExpired()) {
                this.removeSession();
            }
            if (!DrupalConstants.Connection || !DrupalConstants.Connection.token || refreshToken) {
                return this.getToken().pipe(operators.mergeMap(function (token) {
                    return _this.post({}, 'connect').pipe(operators.map(function (connection) {
                        connection.token = token;
                        _this.saveSessionToken(connection);
                        return connection;
                    }));
                }));
            }
            return this.post({}, 'connect').pipe(operators.map(function (connection) {
                _this.saveSessionToken(connection);
                return connection;
            }));
        };
        /**
         * implement get_variable resource
         * @param variableName the name of the variable
         * @return the value of the variable
         */
        SystemService.prototype.getVariable = function (variableName) {
            return this.post({ name: variableName }, 'get_variable');
        };
        /**
         * implement set_variable resource
         * @param variableName the name of the variable
         * @param value the value to set for the variable
         * @return always null, take care of overriding old variables with same name
         */
        SystemService.prototype.setVariable = function (variableName, value) {
            var variable = {
                name: variableName,
                value: value
            };
            return this.post(variable, 'set_variable');
        };
        /**
         * implement del_variable resource
         * @param variableName variable name to delete
         * @return null if variable found or not.
         */
        SystemService.prototype.delVariable = function (variableName) {
            return this.post({ name: variableName }, 'del_variable');
        };
        return SystemService;
    }(MainService));
    SystemService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * user service for drupal
     * @see BACK_END/admin/structure/services/list/END_POINT/resources for more details
     */
    var UserService = /** @class */ (function (_super) {
        __extends(UserService, _super);
        function UserService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            _this.entityType = 'user';
            return _this;
        }
        /**
         * implement retrive resource
         * @param uid user id to retrive
         * @return user object
         */
        UserService.prototype.getUserById = function (uid) {
            return this.get(uid);
        };
        /**
         * implement index resource
         * @return array of users
         * Please notice that the user must have the required permission to do this action
         */
        UserService.prototype.getUsersList = function () {
            return this.get();
        };
        /**
         * implement create resource
         * @param user user to create
         * @return created user details
         */
        UserService.prototype.createUser = function (user) {
            return this.post(user);
        };
        /**
         * implement update resource
         * @param user user object to update
         * @return updated user object
         */
        UserService.prototype.updateUser = function (user) {
            return this.put(user, user.uid);
        };
        /**
         * implement delete
         * @param uid user id to delete
         * @return array of boolean, if user deleted will be true, otherwise will be false
         */
        UserService.prototype.deleteUser = function (uid) {
            return this.delete(uid);
        };
        /**
         * implement login resource
         * @param user credentials to login "username and password"
         * @return system connection that contains the session details and the user object
         * notice that the user login version must be of version 1.0 at the resources settions at the back-end
         */
        UserService.prototype.login = function (user) {
            var _this = this;
            var observer = this.post(user, 'login');
            return observer.pipe(operators.map(function (connection) {
                _this.saveSessionToken(connection);
                return connection;
            }));
        };
        /**
         * implement logout resource
         * @return new token after logging out
         */
        UserService.prototype.logout = function () {
            var _this = this;
            var observer = this.post({}, 'logout');
            return observer.pipe(operators.mergeMap(function (loggedOut) {
                if (loggedOut[0]) {
                    _this.removeSession();
                    return _this.getToken();
                }
            }));
        };
        /**
         * implement request_new_password resource
         * @param useranme the username of the user to request a new password
         * @return array of boolean, if the mail sent successfully will be true, otherwhise will be false.
         * if the server is not a mail server or if there is not mail server configuration this will always return false
         */
        UserService.prototype.requestNewPassword = function (useranme) {
            var user = {
                name: useranme
            };
            return this.post(user, 'request_new_password');
        };
        /**
         * implement user_pass_reset resource
         * @param passwordReset Object of the sent details to the email that contains the timestamp and the hashed password
         * @return response of the password reset request
         * this request will automatically logging the user in for only one time and will be expired after the first use.
         * the hashed password can be found at the drupal reset password email and you can customize it if you have token module installed
         */
        UserService.prototype.userPasswordReset = function (passwordReset) {
            return this.post(passwordReset, 'user_pass_reset');
        };
        /**
         * implement register resource
         * @param user object to register new account
         * some properties is required if it is set at the account settings inside the drupal admin config
         * @see http://BACKEND/admin/config/people/accounts
         * @return created user details
         */
        UserService.prototype.registerAccount = function (user) {
            return this.post(user, 'register');
        };
        /**
         * implement cancel resource
         * @param uid the user id to cancel
         * @return array of boolean, true if canceled, false otherwhise
         * Please notice the cancelation settings is managed at the backend
         * @see http://BACKEND/admin/config/people/accounts
         */
        UserService.prototype.cancelUser = function (uid) {
            return this.post({}, uid + "/cancel");
        };
        /**
         * implement password_reset resource
         * @param uid user id to reset his password
         * @return array of boolean, true if user password has been resetted, false otherwhise
         */
        UserService.prototype.passwordReset = function (uid) {
            return this.post({}, uid + "/password_reset");
        };
        /**
         * implement resend_welcome_email
         * @param uid user id to send the email for his account
         * @return array of boolean, if the mail sent successfully will be true, otherwhise will be false.
         * if the server is not a mail server or if there is not mail server configuration this will always return false
         */
        UserService.prototype.resendWelcomeEmail = function (uid) {
            return this.post({}, uid + "/resend_welcome_email");
        };
        /**
         * implement token
         */
        UserService.prototype.token = function () {
            return this.getToken();
        };
        return UserService;
    }(MainService));
    UserService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * node service for drupal
     * @see BACK_END/admin/structure/services/list/END_POINT/resources for more details
     */
    var NodeService = /** @class */ (function (_super) {
        __extends(NodeService, _super);
        function NodeService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            _this.entityType = 'node';
            return _this;
        }
        /**
         * impelement index resource
         * @return array of nodes
         */
        NodeService.prototype.getAllNodes = function () {
            return this.get();
        };
        /**
         * implement retrive resource
         * @param nid node id to retrive
         * @return object of the node entity
         */
        NodeService.prototype.getNodeById = function (nid) {
            return this.get(nid);
        };
        /**
         * implement create resource
         * @param node node entity to create
         * @return created node details
         */
        NodeService.prototype.createNode = function (node) {
            return this.post(node);
        };
        /**
         * implement create resource
         * @param node node to create
         * @return created node details
         */
        NodeService.prototype.updateNode = function (node) {
            return this.put(node, node.nid);
        };
        /**
         * implement delete resource
         * @param nid node id to delete
         * @return array true if node deleted, otherwise return false array
         */
        NodeService.prototype.deleteNode = function (nid) {
            return this.delete(nid);
        };
        /**
         * implement files resource
         * @param nid node id
         * @return array of files that attached to that node
         */
        NodeService.prototype.files = function (nid) {
            return this.get(nid + "/files");
        };
        /**
        * implement comments resource
        * @param nid node id
        * @return array of comments that attached to that node
        */
        NodeService.prototype.comments = function (nid) {
            return this.get(nid + "/comments");
        };
        /**
        * implement attach_files resource
        * @param nid node id
        * @file object contains the field details and the file to upload
        * @return attached file
        */
        NodeService.prototype.attachFilesToNode = function (nid, file) {
            return this.post(file, nid + "/attach_file");
        };
        return NodeService;
    }(MainService));
    NodeService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * file service for drupal
     * @see BACK_END/admin/structure/services/list/END_POINT/resources for more details
     */
    var FileService = /** @class */ (function (_super) {
        __extends(FileService, _super);
        function FileService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            _this.entityType = 'file';
            return _this;
        }
        /**
         * impelement index resource
         * @return array of files
         */
        FileService.prototype.getAllFiles = function () {
            return this.get();
        };
        /**
         * implement retrive resource
         * @param fid file id to retrive
         * @return object of the file entity
         */
        FileService.prototype.getFileById = function (fid) {
            return this.get(fid);
        };
        /**
         * implement create resource
         * @param file file entity to create
         * @return created file details
         */
        FileService.prototype.createFile = function (file) {
            return this.post(file);
        };
        /**
         * implement delete resource
         * @param fid file id to delete
         * @return boolean array if file deleted, otherwise return false
         * keep in mined that you can not delete a file if it is already referenced by a node
         */
        FileService.prototype.deleteFile = function (fid) {
            return this.delete(fid);
        };
        /**
         * creating raw file
         * this require rest support for form multi data
         */
        FileService.prototype.createRaw = function () {
            return this.post({}, 'create_raw');
        };
        return FileService;
    }(MainService));
    FileService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * comment service for drupal
     * @see BACK_END/admin/structure/services/list/END_POINT/resources for more details
     */
    var CommentService = /** @class */ (function (_super) {
        __extends(CommentService, _super);
        function CommentService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            /**
             * entity type is comment
             */
            _this.entityType = 'comment';
            return _this;
        }
        /**
         * implement comment index resource
         * @return list of comments
         */
        CommentService.prototype.getAllComments = function () {
            return this.get();
        };
        /**
         * implement comment retrive method
         * @param cid comment id
         * @return drupal comment entity
         */
        CommentService.prototype.getCommentById = function (cid) {
            return this.get(cid);
        };
        /**
         * implement create resource
         * @param comment the comment to create
         * @return created comment details
         */
        CommentService.prototype.createComment = function (comment) {
            return this.post(comment);
        };
        /**
         * implement update resource
         * @param comment comment to update
         * @return array of comment id
         */
        CommentService.prototype.updateComment = function (comment) {
            return this.put(comment, comment.cid);
        };
        /**
         * implement delete resource
         * @param cid comment id to delete
         * @return array of boolean, if comment deleted the array will will contains true
         */
        CommentService.prototype.deleteComment = function (cid) {
            return this.delete(cid);
        };
        /**
         * implement countAll resource
         * @param nid host node id of the comments
         * @return number of comments on the node
         */
        CommentService.prototype.countAllCommentsByNodeId = function (nid) {
            return this.post({ nid: nid }, 'countAll');
        };
        /**
         * implement countNew resource.
         * @param nid host node id of the new comments
         * @return number of the new comments for the giving node id
         */
        CommentService.prototype.countNewCommentsByNodeId = function (nid) {
            return this.post({ nid: nid }, 'countNew');
        };
        return CommentService;
    }(MainService));
    CommentService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * taxonomy term service for drupal
     * @see BACK_END/admin/structure/services/list/END_POINT/resources for more details
     */
    var TaxonomyTermService = /** @class */ (function (_super) {
        __extends(TaxonomyTermService, _super);
        function TaxonomyTermService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            _this.entityType = 'taxonomy_term';
            return _this;
        }
        /**
         * implement index resource
         * @return array of terms
         */
        TaxonomyTermService.prototype.getAllTaxonomyTerms = function () {
            return this.get();
        };
        /**
         * implement retrive resource
         * @param tid term id
         * @return term object
         */
        TaxonomyTermService.prototype.getTaxonomyTermById = function (tid) {
            return this.get(tid);
        };
        /**
         * implement create resource
         * @param taxonomyTerm the term to create
         * @return array number for the wight of the term
         */
        TaxonomyTermService.prototype.createTaxonomyTerm = function (taxonomyTerm) {
            return this.post(taxonomyTerm);
        };
        /**
         * implement update resource
         * @param taxonomyTerm term to update
         * @return array number for the wight of the term
         */
        TaxonomyTermService.prototype.updateTaxonomyTerm = function (taxonomyTerm) {
            return this.put(taxonomyTerm, taxonomyTerm.tid);
        };
        /**
         * implement delete resource
         * @param tid term id to delete
         * @return array of deleted term id
         */
        TaxonomyTermService.prototype.deleteTaxonomyTerm = function (tid) {
            return this.delete(tid);
        };
        /**
         * implement selectNodes
         * @param tid term id
         * @return array of nodes that referenced this term in one of the fields
         */
        TaxonomyTermService.prototype.getAllNodesForTerm = function (tid) {
            return this.post({ tid: tid }, 'selectNodes');
        };
        return TaxonomyTermService;
    }(MainService));
    TaxonomyTermService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * taxonomy vocabulary service for drupal
     * @see BACK_END/admin/structure/services/list/END_POINT/resources for more details
     */
    var TaxonomyVocabularyService = /** @class */ (function (_super) {
        __extends(TaxonomyVocabularyService, _super);
        function TaxonomyVocabularyService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            _this.entityType = 'taxonomy_vocabulary';
            return _this;
        }
        /**
         * implement index resource
         * @return array of the available vocabularies
         */
        TaxonomyVocabularyService.prototype.getAllVocabularies = function () {
            return this.get();
        };
        /**
         * implement retrive resource
         * @param vid vocabulary id
         * @return vocabulary object
         */
        TaxonomyVocabularyService.prototype.getTaxonomyVocabularyById = function (vid) {
            return this.get(vid);
        };
        /**
         * implement create resource
         * @param taxonomyVocabulary the vocabulary to create
         * @return array of vocabulary id
         */
        TaxonomyVocabularyService.prototype.createTaxonomyVocabulary = function (taxonomyVocabulary) {
            return this.post(taxonomyVocabulary);
        };
        /**
         * implement update resource
         * @param taxonomyVocabulary the vocabulary to update
         * @return array of the current vocabulary whight
         */
        TaxonomyVocabularyService.prototype.updateTaxonomyVocabulary = function (taxonomyVocabulary) {
            return this.put(taxonomyVocabulary, taxonomyVocabulary.vid);
        };
        /**
         * implement delete resource
         * @param vid vocabulary id to delete
         * @return array of deleted vocabulary id
         */
        TaxonomyVocabularyService.prototype.deleteTaxonomyVocabulary = function (vid) {
            return this.delete(vid);
        };
        /**
         * implement retrieveByMachineName resource
         * @param vocabularyMachineName vocabulary machine name
         * @return vocabulary object
         */
        TaxonomyVocabularyService.prototype.getTaxonomyVocabularyByMachineName = function (vocabularyMachineName) {
            return this.post({ machine_name: vocabularyMachineName }, 'retrieveByMachineName');
        };
        /**
         * implement getTree resource
         * @param vid vocabulary id
         * @return a full list of taxonomy terms inside this vocabulary as a tree structure.
         */
        TaxonomyVocabularyService.prototype.getTaxonomyVocabularyTree = function (vid) {
            return this.post({ vid: vid }, 'getTree');
        };
        return TaxonomyVocabularyService;
    }(MainService));
    TaxonomyVocabularyService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * view service for drupal using services_views module
     * @see https://www.drupal.org/project/services_views
     */
    var ViewService = /** @class */ (function (_super) {
        __extends(ViewService, _super);
        function ViewService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            _this.entityType = 'views';
            return _this;
        }
        /**
         * impelemnt retrive resource
         * @param viewMachineName view machine name
         * @param options parameters of filteration for this view
         * @return array of view rows OR view html code if the options format_output is 1
         */
        ViewService.prototype.getView = function (viewMachineName, options) {
            var args = this.getArgs(options);
            return this.get(viewMachineName + args);
        };
        return ViewService;
    }(MainService));
    ViewService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * custom entity service for drupal using services_entity module
     * @see https://www.drupal.org/project/services_entity
     */
    var EntityService = /** @class */ (function (_super) {
        __extends(EntityService, _super);
        function EntityService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            /**
             * the entity prefix for all the entities
             */
            _this.entityType = 'entity_';
            return _this;
        }
        /**
         * getting the full entity url for the entity
         * @param entityMachineName entity machine name, ex: node, user
         * @return string of full path to resource
         */
        EntityService.prototype.fullRequestURL = function (entityMachineName) {
            var request_url = DrupalConstants.restUrl;
            request_url += this.entityType + entityMachineName;
            return request_url;
        };
        /**
         * implement index resource
         * @param entityMachineName entity machine name, ex: node, user
         * @param options parameter options
         * @return array of the required entity type.
         * personally suggest to create an interface for each type you want to retrive,
         * you can use the models in this module as a perent interfaces.
         */
        EntityService.prototype.indexEntity = function (entityMachineName, options) {
            var args = this.getArgs(options);
            return this.get(entityMachineName + args);
        };
        /**
         * implement retrive resource
         * @param entityMachineName entity machine name, ex: node, user
         * @param selector the id of the entity
         * @param options parameter options
         * @return entity object
         */
        EntityService.prototype.retrieveEntity = function (entityMachineName, selector, options) {
            var args = this.getArgs(options);
            return this.get(entityMachineName + "/" + selector + args);
        };
        /**
         * implement delete resource
         * @param entityMachineName entity machine name, ex: node, user
         * @param selector the id of the entity
         * @return null if the entity is deleted,otherwise throws an error.
         */
        EntityService.prototype.deleteEntity = function (entityMachineName, selector) {
            return this.delete(entityMachineName + "/" + selector);
        };
        /**
         * implement create resource
         * @param entityMachineName entity machine name, ex: node, user
         * @param entity entity object to create
         * @return created entity
         */
        EntityService.prototype.createEntity = function (entityMachineName, entity) {
            return this.post(entity, entityMachineName);
        };
        /**
         * implement update resource
         * @param entityMachineName entity machine name, ex: node, user
         * @param entity entity to update
         * @param selector entity id to update and must match the id inside the entity object
         * @return updated entity
         */
        EntityService.prototype.updateEntity = function (entityMachineName, entity, selector) {
            return this.put(entity, entityMachineName + "/" + selector);
        };
        return EntityService;
    }(MainService));
    EntityService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * menu service for drupal
     * @see https://www.drupal.org/project/services_menu for more details
     */
    var MenuService = /** @class */ (function (_super) {
        __extends(MenuService, _super);
        function MenuService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            _this.entityType = 'menu';
            return _this;
        }
        /**
         * implement menu retrive
         * @param menuMachineName menu machine name
         * @return menu witl all children links
         */
        MenuService.prototype.getMenu = function (menuMachineName) {
            return this.get(menuMachineName);
        };
        return MenuService;
    }(MainService));
    MenuService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * facebook oauth service
     * @see https://www.drupal.org/project/services_fboauth
     * @see BACK_END/admin/structure/services/list/END_POINT/resources for more details
     */
    var FacebookOAuthService = /** @class */ (function (_super) {
        __extends(FacebookOAuthService, _super);
        function FacebookOAuthService() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            _this.entityType = 'fboauth';
            return _this;
        }
        /**
         * if there is already a token in the browser cookies and it is not expired it returns
         * this will fetch a new token before trying to connect
         * @param accessToken string of the recieved access token
         * @return observable of the connect method
         * the subscription data is an object of SystemConnection interface
         */
        FacebookOAuthService.prototype.connect = function (accessToken) {
            var _this = this;
            if (this.isConnectionExpired()) {
                this.removeSession();
            }
            var body = {
                access_token: accessToken
            };
            if (!DrupalConstants.Connection || !DrupalConstants.Connection.token) {
                return this.getToken().pipe(operators.mergeMap(function (token) {
                    return _this.post(body, 'connect').pipe(operators.mergeMap(function (connection) {
                        return _this.getToken().pipe(operators.map(function (newToken) {
                            connection.token = newToken;
                            _this.saveSessionToken(connection);
                            return connection;
                        }));
                    }));
                }));
            }
            return this.post(body, 'connect').pipe(operators.map(function (connection) {
                _this.saveSessionToken(connection);
                return connection;
            }));
        };
        return FacebookOAuthService;
    }(MainService));
    FacebookOAuthService.decorators = [
        { type: core.Injectable }
    ];

    /**
     * view service for drupal using push_notifications module
     * @see https://www.drupal.org/project/push_notifications
     */
    var PushNotificationsSerivce = /** @class */ (function (_super) {
        __extends(PushNotificationsSerivce, _super);
        function PushNotificationsSerivce() {
            var _this = _super.apply(this, __spreadArray([], __read(arguments))) || this;
            _this.entityType = 'push_notifications';
            return _this;
        }
        /**
         * create/register new device with a token
         * @param pushNotifications notification object to register
         */
        PushNotificationsSerivce.prototype.create = function (pushNotifications) {
            return this.post(pushNotifications);
        };
        /**
         * delete a subscription by device token
         * @param token token of the device to be deleted
         */
        PushNotificationsSerivce.prototype.delete_push = function (token) {
            return this.delete(token);
        };
        return PushNotificationsSerivce;
    }(MainService));
    PushNotificationsSerivce.decorators = [
        { type: core.Injectable }
    ];

    /**
     * angular imports
     */
    /**
     * implement APP_INITIALIZER
     * @param systemService system service to connect
     * @see https://gillespie59.github.io/2016/12/04/angular2-code-before-rendering.html
     */
    function init(systemService) {
        return function () {
            var connectionObservable = systemService.connect(true).toPromise();
            return connectionObservable;
        };
    }
    /**
     * main services module with providers
     * if you do not need to import all the services you need to make your own module and import the required providers only
     * ngx-cookie package is required
     * @see https://www.npmjs.com/package/ngx-cookie
     */
    // @dynamic
    var Drupal7ServicesModule = /** @class */ (function () {
        function Drupal7ServicesModule() {
        }
        return Drupal7ServicesModule;
    }());
    Drupal7ServicesModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule,
                    ],
                    providers: [
                        MainService,
                        SystemService,
                        UserService,
                        NodeService,
                        FileService,
                        CommentService,
                        TaxonomyTermService,
                        TaxonomyVocabularyService,
                        ViewService,
                        EntityService,
                        MenuService,
                        FacebookOAuthService,
                        PushNotificationsSerivce,
                        {
                            'provide': core.APP_INITIALIZER,
                            'useFactory': init,
                            'deps': [SystemService],
                            'multi': true
                        }
                    ],
                },] }
    ];

    /*
     * Public API Surface of ngx-drupal7-services
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.CommentService = CommentService;
    exports.Drupal7ServicesModule = Drupal7ServicesModule;
    exports.DrupalConstants = DrupalConstants;
    exports.EntityService = EntityService;
    exports.FacebookOAuthService = FacebookOAuthService;
    exports.FileService = FileService;
    exports.MainService = MainService;
    exports.MenuService = MenuService;
    exports.NodeService = NodeService;
    exports.PushNotificationsSerivce = PushNotificationsSerivce;
    exports.SystemService = SystemService;
    exports.TaxonomyTermService = TaxonomyTermService;
    exports.TaxonomyVocabularyService = TaxonomyVocabularyService;
    exports.UserService = UserService;
    exports.ViewService = ViewService;
    exports.init = init;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-drupal7-services.umd.js.map
